Class: MiqDevUtil::Code

Inherits:
Object
  • Object
show all
Defined in:
lib/miq_dev_util/code.rb

Overview

The Code class is a container for miscellaneous methods that a developer may find useful. The focus is on standard Ruby oriented tasks that could apply outside of the ManageIQ environment.

Class Method Summary collapse

Class Method Details

.deep_copy(o) ⇒ Object

Perform a deep copy on objects that support marshalling.



7
8
9
# File 'lib/miq_dev_util/code.rb', line 7

def self.deep_copy(o)
  Marshal.load(Marshal.dump(o))
end