Class: MiqDevUtil::EMS
- Inherits:
-
Object
- Object
- MiqDevUtil::EMS
- Defined in:
- lib/miq_dev_util/ems.rb
Overview
The External Management System (EMS) class holds methods that apply to EMS objects in ManageIQ.
Class Method Summary collapse
-
.get_credentials(ems, insecure = true) ⇒ Object
Return a hash containing the attributes that are commonly used to connect directly to the EMS.
Class Method Details
.get_credentials(ems, insecure = true) ⇒ Object
Return a hash containing the attributes that are commonly used to connect directly to the EMS.
-
:host
-
:user
-
:password
-
:insecure
11 12 13 14 15 16 17 18 |
# File 'lib/miq_dev_util/ems.rb', line 11 def self.get_credentials(ems, insecure=true) { host: ems['hostname'], user: ems.authentication_userid, password: ems.authentication_password, insecure: insecure } end |